Package: shinyFeedback
Type: Package
Title: Display User Feedback in Shiny Apps
Version: 0.4.0
Date: 2021-09-23
Authors@R: c(
  person("Andy", "Merlino", email = "andy.merlino@tychobra.com", role = c("aut", "cre")),
  person("Patrick", "Howard", email = "patrick.howard@tychobra.com", role = c("aut")))
Description: Easily display user feedback in Shiny apps.
License: MIT + file LICENSE
Depends: R (>= 3.1.2)
RoxygenNote: 7.1.2
Encoding: UTF-8
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Imports: fontawesome, htmltools, jsonlite, shiny
URL: https://github.com/merlinoa/shinyFeedback
BugReports: https://github.com/merlinoa/shinyFeedback/issues
NeedsCompilation: no
Packaged: 2021-09-23 17:26:42 UTC; andy
Author: Andy Merlino [aut, cre],
  Patrick Howard [aut]
Maintainer: Andy Merlino <andy.merlino@tychobra.com>
Repository: CRAN
Date/Publication: 2021-09-23 18:30:08 UTC
Built: R 4.6.0; ; 2026-04-26 11:13:23 UTC; unix
