# Generated by roxygen2: do not edit by hand

export(feedback)
export(feedbackDanger)
export(feedbackSuccess)
export(feedbackWarning)
export(hideFeedback)
export(hideToast)
export(loadingButton)
export(resetLoadingButton)
export(showFeedback)
export(showFeedbackDanger)
export(showFeedbackSuccess)
export(showFeedbackWarning)
export(showToast)
export(useShinyFeedback)
export(valueBoxModule)
export(valueBoxModuleUI)
importFrom(fontawesome,fa_html_dependency)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,singleton)
importFrom(htmltools,span)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(jsonlite,toJSON)
importFrom(shiny,NS)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,icon)
importFrom(shiny,is.reactive)
importFrom(shiny,isTruthy)
importFrom(shiny,reactive)
importFrom(shiny,renderText)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
