# shinyFeedback <img src="https://raw.githubusercontent.com/merlinoa/shinyFeedback/master/inst/img/shinyfeedback_hex_sticker.png" align="right" width="120" />

[![Travis-CI Build Status](https://travis-ci.org/merlinoa/shinyFeedback.svg?branch=master)](https://travis-ci.org/merlinoa/shinyFeedback) [![CRAN](https://www.r-pkg.org/badges/version/shinyFeedback)](https://cran.r-project.org/package=shinyFeedback) [![Downloads](https://cranlogs.r-pkg.org/badges/shinyFeedback)](https://www.r-pkg.org/pkg/shinyFeedback)

R package for displaying user feedback alongside Shiny inputs

![](https://raw.githubusercontent.com/merlinoa/shinyFeedback/master/inst/img/feedback_screenshot.png)

### [Live Shiny app using `shinyFeedback`](https://tychobra.shinyapps.io/supported_inputs_app/)

# Getting Started

### Install from CRAN

```R
install.packages("shinyFeedback")
```

### Or install the development version from GitHub

```R
remotes::install_github("merlinoa/shinyFeedback", build_vignettes = TRUE)
```
### Read Intro Vignette

```R
# load package
library(shinyFeedback)
# read intro vignette
browseVignettes(package = "shinyFeedback")
```
